% 3 DOF system for lecture notes
clear;clf;close all;
N=3; 

m_n=1;
k_n=1;
c_n=0.2;
fsize=12;
% Undamped System matrices
M = [m_n 0 0;0 m_n 0;0 0 m_n];
K=[2*k_n -k_n 0; -k_n 2*k_n -k_n;0 -k_n 2*k_n];
[X,omega]=UndampedEigen(K,M);

%Damping matrix
C=[c_n 0 0;0 c_n 0;0 0 c_n];
zeta=(c_n/m_n)/2./omega;
omegad=omega.*sqrt(1-zeta.^2);

% Create time & frequency array
om_max=1.3*omega(3);
freq=[0.001:om_max/100:om_max]';nf=length(freq);

tm_max=3*(2*pi)/omega(1);
time=[0:tm_max/99:tm_max]';nt=length(time);

% Response calculation: Step @ DOF 1
t_0 = 2*pi/omega(1)/16;
% Load case 1, f(t) = 1 - U(t-t_0)
qbar1=zeros(nf,N);
for j=1:N
    denom(:,j)=-freq.^2+2*i*zeta(j)*omega(j)+omega(j)^2;
    fom=1.0-exp(-i.*freq*t_0)./(i*freq);
    termj(:,j)=X(1,j)*fom./denom(:,j);
end
for k=1:N
    for j=1:N
        qbar1(:,k)=qbar1(:,k)+termj(:,j)*X(k,j);
    end
end

figure(1)
semilogy(...
         freq,abs(qbar1(:,1)),'-', ...
         freq,abs(qbar1(:,2)),'-.',...
         freq,abs(qbar1(:,3)),'--',...
        'linewidth',1.5)    
axis([0 om_max -0.06 10]);    
hl2=legend('DOF 1','DOF 2','DOF 3');
xlabel('frequency (\omega) - rad/s','fontname','times','FontSize',fsize);
ylabel('Dynamic response, |q(i\omega)|','fontname','times','FontSize',fsize');
set(hl2,'linewidth',2,'FontName','Times','FontSize',fsize);
ha=gca;set(ha,'linewidth',2,'FontName','Times','FontSize',fsize);
    
    
q1=zeros(nt,N);
for j=1:N
    t1=zeta(j)*omega(j);
    alpha(j)=(omegad(j)*sin(omegad(j)*t_0)+t1*cos(omegad(j)*t_0))*exp(t1*t_0)-t1;
    beta(j) =(omegad(j)*cos(omegad(j)*t_0)-t1*sin(omegad(j)*t_0))*exp(t1*t_0)-omegad(j);
    term1j(:,j)=X(1,j)/(omegad(j)*omega(j)^2)*exp(-t1*time).*...
        (alpha(j)*sin(omegad(j)*time) + beta(j)*cos(omegad(j)*time) );
end
for k=1:N
    for j=1:N
        q1(:,k)=q1(:,k)+term1j(:,j)*X(k,j);
    end
end

figure(2)
plot(...
         time,(q1(:,1)),'-', ...
         time,(q1(:,2)),'-.',...
         time,(q1(:,3)),'--',...
        'linewidth',1.5)    
axis([0 tm_max -0.4 0.4]);    
hl2=legend('DOF 1','DOF 2','DOF 3');
xlabel('Time (sec)','fontname','times','FontSize',fsize);
ylabel('Dynamic response, q(t)','fontname','times','FontSize',fsize');
set(hl2,'linewidth',2,'FontName','Times','FontSize',fsize);
ha=gca;set(ha,'linewidth',2,'FontName','Times','FontSize',fsize);
    
%               Response calculation: unit displacement @ DOF 2
%                           Load case 2
qbar2=zeros(nf,N);termj=zeros(size(termj));;
for j=1:N
    numer=(X(2,j)*m_n)*(2*zeta(j)*omega(j)*ones(size(freq))+i*freq);
    termj(:,j)=numer./denom(:,j);
end
for k=1:N
    for j=1:N
        qbar2(:,k)=qbar2(:,k)+termj(:,j)*X(k,j);
    end
end

figure(3)
semilogy(...
         freq,abs(qbar2(:,1)),'-', ...
         freq,abs(qbar2(:,2)),'-.',...
         freq,abs(qbar2(:,3)),'--',...
        'linewidth',1.5)    
axis([0 om_max -0.06 10]);    
hl2=legend('DOF 1','DOF 2','DOF 3');
xlabel('frequency (\omega) - rad/s','fontname','times','FontSize',fsize);
ylabel('Dynamic response, |q(i\omega)|','fontname','times','FontSize',fsize');
set(hl2,'linewidth',2,'FontName','Times','FontSize',fsize);
ha=gca;set(ha,'linewidth',2,'FontName','Times','FontSize',fsize);
    
q2=zeros(nt,N);term1j=zeros(size(term1j));
for j=1:N
    t1=zeta(j)*omega(j);
    term1j(:,j)=(X(2,j)*m_n)*exp(-t1*time).*cos(omegad(j)*time);
end
for k=1:N
    for j=1:N
        q2(:,k)=q2(:,k)+term1j(:,j)*X(k,j);
    end
end
figure(4)
plot(...
         time,(q2(:,1)),'-', ...
         time,(q2(:,2)),'-.',...
         time,(q2(:,3)),'--',...
        'linewidth',1.5)    
axis([0 tm_max -0.6 1]);    
hl2=legend('DOF 1','DOF 2','DOF 3');
xlabel('Time (sec)','fontname','times','FontSize',fsize);
ylabel('Dynamic response, q(t)','fontname','times','FontSize',fsize');
set(hl2,'linewidth',2,'FontName','Times','FontSize',fsize);
ha=gca;set(ha,'linewidth',2,'FontName','Times','FontSize',fsize);



%               Response calculation: unit velocity @ DOF 2 & DOF 3
%                           Load case 3
qbar3=zeros(nf,N);termj=zeros(size(termj));;
for j=1:N
    termj(:,j)=((X(2,j)+X(3,j))*m_n)./denom(:,j);
end
for k=1:N
    for j=1:N
        qbar3(:,k)=qbar3(:,k)+termj(:,j)*X(k,j);
    end
end

figure(5)
semilogy(...
         freq,abs(qbar3(:,1)),'-', ...
         freq,abs(qbar3(:,2)),'-.',...
         freq,abs(qbar3(:,3)),'--',...
        'linewidth',1.5)    
axis([0 om_max -0.06 10]);    
hl2=legend('DOF 1','DOF 2','DOF 3');
xlabel('frequency (\omega) - rad/s','fontname','times','FontSize',fsize);
ylabel('Dynamic response, |q(i\omega)|','fontname','times','FontSize',fsize');
set(hl2,'linewidth',2,'FontName','Times','FontSize',fsize);
ha=gca;set(ha,'linewidth',2,'FontName','Times','FontSize',fsize);
    
q3=zeros(nt,N);term1j=zeros(size(term1j));
for j=1:N
    t1=zeta(j)*omega(j);
    term1j(:,j)=((X(2,j)+X(3,j))*m_n)*exp(-t1*time).*sin(omegad(j)*time)/omegad(j);
end
for k=1:N
    for j=1:N
        q3(:,k)=q3(:,k)+term1j(:,j)*X(k,j);
    end
end
figure(6)
plot(...
         time,(q3(:,1)),'-', ...
         time,(q3(:,2)),'-.',...
         time,(q3(:,3)),'--',...
        'linewidth',1.5)    
axis([0 tm_max -0.6 1]);    
hl2=legend('DOF 1','DOF 2','DOF 3');
xlabel('Time (sec)','fontname','times','FontSize',fsize);
ylabel('Dynamic response, q(t)','fontname','times','FontSize',fsize');
set(hl2,'linewidth',2,'FontName','Times','FontSize',fsize);
ha=gca;set(ha,'linewidth',2,'FontName','Times','FontSize',fsize);


figure(7)
plot(...
         time,q1(:,1)+q2(:,1)+q3(:,1),'-', ...
         time,q1(:,2)+q2(:,2)+q3(:,2),'-.',...
         time,q1(:,3)+q2(:,3)+q3(:,3),'--',...
        'linewidth',1.5)    
% axis([0 tm_max -0.6 1]);    
hl2=legend('DOF 1','DOF 2','DOF 3');
xlabel('Time (sec)','fontname','times','FontSize',fsize);
ylabel('Dynamic response, q(t)','fontname','times','FontSize',fsize');
set(hl2,'linewidth',2,'FontName','Times','FontSize',fsize);
ha=gca;set(ha,'linewidth',2,'FontName','Times','FontSize',fsize);


save_fig=input('Save figures (Adjust before saving)? [y,n] ','s');
if save_fig == 'y'
    for j=1:3
        figure(2*j-1)
        eval(['print -depsc2 ../figs/freq_cs' num2str(j) '.eps']);
    
        figure(2*j)
        eval(['print -depsc2 ../figs/time_cs' num2str(j) '.eps']);
    end
end
    